@@ -2,6 +2,7 @@ package Function::Parameters;
 
 use v5.14.0;
 use warnings;
+use warnings::register;
 
 use Carp qw(croak confess);
 use Scalar::Util qw(blessed);
@@ -13,11 +14,15 @@ sub _croak {
 
 use XSLoader;
 BEGIN {
-    our $VERSION = '2.001004';
+    our $VERSION = '2.001006';
     #$VERSION =~ s/-TRIAL[0-9]*\z//;
     XSLoader::load;
 }
 
+sub _warn_config_not_a_reference {
+    warnings::warnif sprintf q{%s: $^H{'%s'} is not a reference; skipping: %s}, __PACKAGE__, HINTK_CONFIG, $^H{+HINTK_CONFIG};
+}
+
 sub _assert_valid_identifier {
     my ($name, $with_dollar) = @_;
     my $bonus = $with_dollar ? '\$' : '';
@@ -1569,7 +1574,7 @@ Type reifiers used to see the wrong package in
 L<C<caller>|perlfunc/caller EXPR>. As a workaround the correct calling package
 used to be passed as a second argument. This problem has been fixed and the
 second argument has been removed. (Technically this is a core perl bug
-(L<RT #129239|https://rt.perl.org/Public/Bug/Display.html?id=129239>) that
+(L<GH #15597|https://github.com/Perl/perl5/issues/15597>) that
 wasn't so much fixed as worked around in C<Function::Parameters>.)
 
 If you want your type reifier to be compatible with both versions, you can do
@@ -1589,6 +1594,40 @@ Or using C<Function::Parameters> itself:
 
 =back
 
+=head1 DIAGNOSTICS
+
+=over
+
+=item Function::Parameters: $^H{'Function::Parameters/config'} is not a reference; skipping: HASH(...)
+
+Function::Parameters relies on being able to put references in C<%^H> (the
+lexical compilation context) and pull them out again at compile time. You may
+see the warning above if what used to be a reference got turned into a plain
+string. In this case, Function::Parameters gives up and automatically disables
+itself, as if by C<no Function::Parameters;>.
+
+You can disable the warning by saying C<no warnings 'Function::Parameters';>.
+
+Currently the only case I'm aware of where this happens with core perl is
+embedded code blocks in regexes that are compiled at runtime (in a scope where
+L<C<use re 'eval'>|re> is active):
+
+    use strict;
+    use warnings;
+    use Function::Parameters;
+    use re 'eval';
+
+    my $code = '(?{ print "embedded code\n"; })';
+    my $regex = qr/$code/;
+
+In my opinion, this is a bug in perl: L<GH
+#20950|https://github.com/Perl/perl5/issues/20950>.
+
+This case used to be a hard error in versions 2.001005 and before of this
+module.
+
+=back
+
 =begin :README
 
 =head1 INSTALLATION
@@ -1645,12 +1684,12 @@ Lukas Mai, C<< <l.mai at web.de> >>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright (C) 2010-2014, 2017 Lukas Mai.
+Copyright (C) 2010-2014, 2017, 2023 Lukas Mai.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
 by the Free Software Foundation; or the Artistic License.
 
-See L<http://dev.perl.org/licenses/> for more information.
+See L<https://dev.perl.org/licenses/> for more information.
 
 =cut
